# User Guide

## Getting started
1. [What is QuGrad](getting_started.md#what-is-qugrad)
2. [Installation](getting_started.md#installation)
3. [Quick Start](getting_started.md#quick-start)

## Features

- [Pulse Forms](pulse_forms.md)
- [Examples](examples.md)

## Running Tests

 - [Running Tests](running_tests.md)

---
[Next](getting_started.md)